const csvUrl =
  'https://gist.githubusercontent.com/snlgrglns/e0a53c383117c785b9de5faf8c8fdfb5/raw/d5ef0b8af5f8ccd4fd511c737691e1dc392a339f/IRIS_DataSet.csv'

// Give the points a 3D feel by adding a radial gradient
Highcharts.setOptions({
    colors: Highcharts.getOptions().colors.map(function (color) {
        return {
            radialGradient: {
                cx: 0.4,
                cy: 0.3,
                r: 0.5
            },
            stops: [
                [0, color],
                [1, Highcharts.color(color).brighten(-0.2).get('rgb')]
            ]
        };
    })
});
var irisData = [];
d3.csv(csvUrl, (data) => {
  data.forEach(d => {
        // var row = [];
    		// row.push();      	
      irisData.push([+d['petal_length'],+d['sepal_length'],+d['petal_width']]);
    });	
  // Set up the chart
var chart = new Highcharts.Chart({
    chart: {
        renderTo: 'container',
        margin: 100,
        type: 'scatter3d',
        animation: false,
        options3d: {
            enabled: true,
            alpha: 10,
            beta: 30,
            depth: 250,
            viewDistance: 5,
            fitToPlot: false,
            frame: {
                bottom: { size: 1, color: 'rgba(0,0,0,0.02)' },
                back: { size: 1, color: 'rgba(0,0,0,0.04)' },
                side: { size: 1, color: 'rgba(0,0,0,0.06)' }
            }
        }
    },
    title: {
        text: '3D Scatter Plot using IRIS Dataset'
    },
    plotOptions: {
        scatter: {
            width: 7,
            height: 4,
            depth: 3
        }
    },
    yAxis: {
        min: 2,
        max: 10,
    },
    xAxis: {
        min: 1,
        max: 7,
        gridLineWidth: 1,
    },
    zAxis: {
        min: 0,
        max: 3,
        showFirstLabel: false
    },
    legend: {
        enabled: true
    },
    series: [{
        name: 'Iris Data',
        colorByPoint: true,
        accessibility: {
            exposeAsGroupOnly: true
        },
        data: irisData
    }]
});
(function (H) {
    function dragStart(eStart) {
        eStart = chart.pointer.normalize(eStart);

        var posX = eStart.chartX,
            posY = eStart.chartY,
            alpha = chart.options.chart.options3d.alpha,
            beta = chart.options.chart.options3d.beta,
            sensitivity = 5,  // lower is more sensitive
            handlers = [];

        function drag(e) {
            // Get e.chartX and e.chartY
            e = chart.pointer.normalize(e);

            chart.update({
                chart: {
                    options3d: {
                        alpha: alpha + (e.chartY - posY) / sensitivity,
                        beta: beta + (posX - e.chartX) / sensitivity
                    }
                }
            }, undefined, undefined, false);
        }

        function unbindAll() {
            handlers.forEach(function (unbind) {
                if (unbind) {
                    unbind();
                }
            });
            handlers.length = 0;
        }

        handlers.push(H.addEvent(document, 'mousemove', drag));
        handlers.push(H.addEvent(document, 'touchmove', drag));


        handlers.push(H.addEvent(document, 'mouseup', unbindAll));
        handlers.push(H.addEvent(document, 'touchend', unbindAll));
    }
    H.addEvent(chart.container, 'mousedown', dragStart);
    H.addEvent(chart.container, 'touchstart', dragStart);
}(Highcharts));
});
console.log(irisData); 